#!/bin/sh -efu
#
# Variables below must be defined before script runs
readonly php_extconf="${php_extconf:?}"
readonly php_sysconfdir="${php_sysconfdir:?}"

[ -d "$php_extconf" -a -d "$php_sysconfdir" ] || exit 0

readonly sapiList="${sapiList:=`find "$php_sysconfdir" -mindepth 1 -maxdepth 1 -type d -printf '%f '`}"
readonly extList="${extList:=`find "$php_extconf" -mindepth 1 -maxdepth 1 -type d -printf '%f '`}"
readonly suffix='phpnew'

for ext in $extList; do
	module_config="$php_extconf/$ext/config"
	module_params="$php_extconf/$ext/params"

	[ -f "$module_params" -a -f "$module_config" ] ||
		continue

	file_ini=
	exceptions=

	. "$module_params"

	config_ini="${file_ini:=$ext.ini}"
	exceptions=" $exceptions "

	for sapi in $sapiList; do

		# extra check to assure the sapi is really installed
		[ -f "$php_sysconfdir/$sapi/php.ini" ] ||
			continue

		[ -n "${exceptions##* $sapi *}" ] ||
			continue

		cur_config="$php_sysconfdir/$sapi/php.d/$config_ini"

		if [ -f "$cur_config" ] && ! cmp -s "$module_config" "$cur_config"; then
			cp "$module_config" "$cur_config.$suffix"
			echo "warning: $cur_config created as $cur_config.$suffix" >&2
			continue
		fi
		cp "$module_config" "$cur_config"

	done
done
